@@ -10,7 +10,6 @@ from bot.helptexts import (
     notesshelp,
     lockktypes,
     lockhelpp,
-    fedhelpp,
     ruless,
 )
 from telethon import events, functions, Button
@@ -52,10 +51,6 @@ async def _(event):
 async def _(event):
     await event.edit(f"{welcomehelpp}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
 
-@callback("fedhelp")
-async def _(event):
-    await event.edit(f"{fedhelpp}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
-
 @callback("ruleshelp")
 async def _(event):
     await event.edit(f"{ruless}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
